Get started with Document-to-Podcast using one of the two options below: **GitHub Codespaces** for a hassle-free setup or **Local Installation** for running on your own machine.

---

### ☁️ **Option 1: GitHub Codespaces**

The fastest way to get started. Click the button below to launch the project directly in GitHub Codespaces:

[![Open in GitHub Codespaces](https://github.com/codespaces/badge.svg)](https://github.com/codespaces/new?hide_repo_select=true&ref=main&repo=888426876&skip_quickstart=true&machine=standardLinux32gb)

Once the Codespaces environment launches, inside the terminal, start the Streamlit demo by running:
```bash
python -m streamlit run demo/app.py
```


### 💻  **Option 2: Local Installation**
1.**Clone the Repository**

Inside your terminal, run:
```bash
   git clone https://github.com/mozilla-ai/document-to-podcast.git
   cd document-to-podcast
```
2. **Install Dependencies**

   Inside your terminal, run:

```bash
pip install -e .
```
3. **Run the Demo**

   Inside your terminal, start the Streamlit demo by running:

```bash
python -m streamlit run demo/app.py
```


### [Optional]: Use Parler models for text-to-speech

If you want to use the [parler tts](https://github.com/huggingface/parler-tts) models, you will need to **additionally** install an optional dependency by running:
```bash
pip install -e '.[parler]'
```
